# wf_core_data

Python tools for working with Wildflower Schools core data

## Tasks
* Add method(s) to extract the current info for each student
* Add method(s) to suggest and review student dupes
* Generalize student ID generation to other objects (teachers, schools, hubs, etc.)
